# Generated by Django 5.2.5 on 2025-10-22 11:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('powercrud', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='BulkTask',
        ),
    ]
